Package 'copulaSFM'

Title: Copula based Simultanous stochastic frontier
Description: The pacage provide a flexible way to mesure the technical efficiency of the production function
Authors: Woraphon Yamaka
Maintainer: The package maintainer <[email protected]>
License: COEE.01
Version: 0.1.0
Built: 2026-05-20 08:54:15 UTC
Source: https://github.com/woraphonyamaka/copulasfm

Help Index


Copula based Stochastic frontier Model

Description

In the standard stochastic frontier model, the two-sided error term V and the one-sided technical inefficiency error term W are assumed to be independent. In this paper, we relax this assumption by modeling the dependence between V and W using copulas. Nine copula families are considered and their parameters are estimated using maximum simulated likelihood.

Usage

copSFM(Y,X,family=1,RHO=0.5,LB=-0.99,UB=0.99)

Arguments

Y

vector of dependent variable

X

matrix of independent variable

family

Copula function eg. Gaussain=1, Student-t=2 (see, Vinecopula package)

RHO

The initail value of the copula parameter

LB

The lower bound of the copula parameter

UB

The upper bound of the copula parameter

Details

herefore, the above copula families and relevant rotated copula can potentially capture the appropriate dependence between two random variables. Other popular copula families, such as Gaussain, Student,t Clayton, Gumbel etc.

Value

result

The result contain the estimated parameters, standard errors, t-stat, and p-value

AIC

Akaiki Information Criteria

BIC

Bayesian Information Criteria

Loglikelihood

Maximum Log-likelihood function

Author(s)

Woraphon Yamaka and Paravee MAneejuk

References

Wiboonpongse, A., Liu, J., Sriboonchitta, S., & Denoeux, T.(2015). Modeling dependence between error components of the stochastic frontier model using copula: application to intercrop coffee production in Northern Thailand. International Journal of Approximate Reasoning, 65, 34-44.

Maneejuk, P., Yamaka, W., & Sriboonchitta, S.(2017). Analysis of global competitiveness using copula-based stochastic frontier kink model. In Robustness in Econometrics (pp. 543-559). Springer, Cham.

Examples

## Required packages
library(truncnorm)
library(mvtnorm)
library("VineCopula")
library("frontier")

#example simulation data
data=sfa.simu(nob=200, alpha=c(1,2,0.5),sigV=1,sigU=0.5,family=1,rho=0.5)

# Select familty  copula upper and lower bouubd ( look at CDVine package)
# family=1   # 1 is Gaussian, 2 is Student-t, 3 is Clayton and so on....

#Gaussian (-.99, .99)
#Student t (-.99, .99)
#Clayton (0.1, Inf)
model=copSFM(Y=data$Y,X=data$X,family=1,RHO=0.5,LB=-0.99,UB=0.99)

Technical efficiency measure.

Description

Computing and plotting the technical efficiency.

Usage

TE(theta,Y,X,family=1)

Arguments

theta

The estimated parameters form the model

Y

Vector of dependent variable

X

Matrix of independent variable

family

Copula function eg. Gaussain=1, Student-t=2 (see, Vinecopula package)

Details

Computing and plotting the technical efficiency.

Value

itemOutput Technical efficiency series itemplot Plot of Technical efficiency

Author(s)

Woraphon Yamaka

References

Wiboonpongse, A., Liu, J., Sriboonchitta, S., & Denoeux, T. (2015). Modeling dependence between error components of the stochastic frontier model using copula: application to intercrop coffee production in Northern Thailand. International Journal of Approximate Reasoning, 65, 34-44.

Examples

## Required packages
library(truncnorm)
library(mvtnorm)
library("VineCopula")
library("frontier")

#example simulation data
data=sfa.simu(nob=200, alpha=c(1,2,0.5),sigV=1,sigU=0.5,family=1,rho=0.5)

# Select familty  copula upper and lower bouubd ( look at CDVine package)
# family=1   # 1 is Gaussian, 2 is Student-t, 3 is Clayton and so on....

#Gaussian (-.99, .99)
#Student t (-.99, .99)
#Clayton (0.1, Inf)

model=copSFM(Y=data$Y,X=data$X,family=1,RHO=0.5,LB=-0.99,UB=0.99)

#EX: Plot the technical efficiency
te1=TE1(model$result[,1],Y=data$Y,X=data$X,family=1)